@@ -4,8 +4,8 @@ Droidrun Agent Module.
 This module provides a ReAct agent for automating Android devices using reasoning and acting.
 """
 
-from ..codeact.codeact_agent import CodeActAgent
-from .droid_agent import DroidAgent
+from droidrun.agent.codeact.codeact_agent import CodeActAgent
+from droidrun.agent.droid.droid_agent import DroidAgent
 
 __all__ = [
     "CodeActAgent",
