@@ -4,6 +4,6 @@ DroidRun CLI Module.
 This module provides command-line interfaces for interacting with Android devices.
 """
 
-from .main import cli
+from droidrun.cli.main import cli
 
 __all__ = ["cli"] 
\ No newline at end of file
